/*
Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'docprops', 'ko', {
	bgColor: '배경 색상',
	bgFixed: '스크롤 되지 않는(고정된) 배경',
	bgImage: '배경 이미지 주소(URL)',
	charset: '문자열 인코딩',
	charsetASCII: 'ASCII',
	charsetCE: '중앙 유럽',
	charsetCR: '키릴 문자',
	charsetCT: '중국어 (Big5)',
	charsetGR: '그리스어',
	charsetJP: '일본어',
	charsetKR: '한국어',
	charsetOther: '다른 문자열 인코딩',
	charsetTR: '터키어',
	charsetUN: '유니코드 (UTF-8)',
	charsetWE: '서유럽',
	chooseColor: '선택',
	design: '디자인',
	docTitle: '페이지 이름',
	docType: '문서 제목',
	docTypeOther: '다른 문서 제목',
	label: '문서 속성',
	margin: '페이지 여백',
	marginBottom: '아래',
	marginLeft: '왼쪽',
	marginRight: '오른쪽',
	marginTop: '위',
	meta: '메타 데이터',
	metaAuthor: '작성자',
	metaCopyright: '저작권',
	metaDescription: '문서 설명',
	metaKeywords: '문서 핵심어 (쉼표로 구분)',
	other: '기타...',
	previewHtml: '<p>이것은 <strong>예문</strong>입니다. 여러분은 지금 <a href="javascript:void(0)">CKEditor</a>를 사용하고 있습니다.</p>',
	title: '문서 속성',
	txtColor: '글자 색상',
	xhtmlDec: 'XHTML 문서 정의 포함'
} );
